caellion-python-commons: tests.test_encoding_base36.TestEncodingBase36Coder Class Reference

caellion-python-commons

Public Member Functions | List of all members
tests.test_encoding_base36.TestEncodingBase36Coder Class Reference

## Public Member Functions
def | test_encoding_base36_init_too_short (self)
def | test_encoding_base36_init_too_long (self)
def | test_encoding_base36_init_length_ok_double_char (self)
def | test_encoding_base36_init_ok (self)
def | test_encoding_base36_to_std_charset_invalid_input (self)
def | test_encoding_base36_to_std_charset_valid_input (self, input, output)
def | test_encoding_base36_to_custom_charset_invalid_input (self)
def | test_encoding_base36_to_custom_charset_valid_input (self, input, output)
def | test_encoding_base36_int_to_base36_negative (self)
def | test_encoding_base36_bytes_to_b36_default_charset_valid_input (self, input, output)
def | test_encoding_base36_int_to_b36_default_charset_valid_input (self, input, output)
def | test_encoding_base36_to_int_negative (self)
def | test_encoding_base36_to_int_valid_input (self, input, output)
def | test_encoding_base36_to_bytes_negative (self)
def | test_encoding_base36_to_bytes_valid_input (self, input, output)
def | test_encoding_base36_to_bytes_too_large (self)

## Detailed Description

Definition at line 15 of file test_encoding_base36.py.

## Member Function Documentation

## ◆ test_encoding_base36_bytes_to_b36_default_charset_valid_input()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_bytes_to_b36_default_charset_valid_input | ( |  | self,
|  |  | input,
|  |  | output
| ) |  |

Definition at line 92 of file test_encoding_base36.py.

## ◆ test_encoding_base36_init_length_ok_double_char()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_init_length_ok_double_char | ( |  | self | ) |

Definition at line 29 of file test_encoding_base36.py.

## ◆ test_encoding_base36_init_ok()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_init_ok | ( |  | self | ) |

Definition at line 33 of file test_encoding_base36.py.

## ◆ test_encoding_base36_init_too_long()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_init_too_long | ( |  | self | ) |

Definition at line 25 of file test_encoding_base36.py.

## ◆ test_encoding_base36_init_too_short()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_init_too_short | ( |  | self | ) |

Definition at line 21 of file test_encoding_base36.py.

## ◆ test_encoding_base36_int_to_b36_default_charset_valid_input()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_int_to_b36_default_charset_valid_input | ( |  | self,
|  |  | input,
|  |  | output
| ) |  |

Definition at line 113 of file test_encoding_base36.py.

## ◆ test_encoding_base36_int_to_base36_negative()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_int_to_base36_negative | ( |  | self | ) |

Definition at line 69 of file test_encoding_base36.py.

## ◆ test_encoding_base36_to_bytes_negative()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_to_bytes_negative | ( |  | self | ) |

Definition at line 144 of file test_encoding_base36.py.

## ◆ test_encoding_base36_to_bytes_too_large()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_to_bytes_too_large | ( |  | self | ) |

Definition at line 170 of file test_encoding_base36.py.

## ◆ test_encoding_base36_to_bytes_valid_input()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_to_bytes_valid_input | ( |  | self,
|  |  | input,
|  |  | output
| ) |  |

Definition at line 165 of file test_encoding_base36.py.

## ◆ test_encoding_base36_to_custom_charset_invalid_input()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_to_custom_charset_invalid_input | ( |  | self | ) |

Definition at line 53 of file test_encoding_base36.py.

## ◆ test_encoding_base36_to_custom_charset_valid_input()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_to_custom_charset_valid_input | ( |  | self,
|  |  | input,
|  |  | output
| ) |  |

Definition at line 64 of file test_encoding_base36.py.

## ◆ test_encoding_base36_to_int_negative()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_to_int_negative | ( |  | self | ) |

Definition at line 118 of file test_encoding_base36.py.

## ◆ test_encoding_base36_to_int_valid_input()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_to_int_valid_input | ( |  | self,
|  |  | input,
|  |  | output
| ) |  |

Definition at line 139 of file test_encoding_base36.py.

## ◆ test_encoding_base36_to_std_charset_invalid_input()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_to_std_charset_invalid_input | ( |  | self | ) |

Definition at line 37 of file test_encoding_base36.py.

## ◆ test_encoding_base36_to_std_charset_valid_input()

def tests.test_encoding_base36.TestEncodingBase36Coder.test_encoding_base36_to_std_charset_valid_input | ( |  | self,
|  |  | input,
|  |  | output
| ) |  |

Definition at line 48 of file test_encoding_base36.py.

The documentation for this class was generated from the following file:

- tests/test_encoding_base36.py